#ifndef __AMI_H
#define __AMI_H
#include "amitype.h"

extern gboolean use_trigger, use_offkey, use_tcp, use_local;
extern XIMTriggerKey *trigger_keys;
extern XIMTriggerKeys *on_keys;
extern XIMTriggerKey *hanja_keys;
extern XIMTriggerKey *special_char_keys;
extern XIMTriggerKey *flush_keys;
extern XIMTriggerKey *forward_keys;
extern char *default_fontname;
extern char *hanja_dic_filename;


extern XIMS	xims;
extern char *hangul_mode_label;
extern char *english_mode_label;
extern long filter_mask;
extern GdkFont	*default_xim_font;
extern GtkWidget *cp, *cp_win;
extern GdkPixmap *dim_mask;
extern int debug;
extern int ami_hanja_def_subst_mode;
extern int ami_hanja_subst_mode;
extern char *ami_hanja_subst_format;

extern int ami_init_im(GtkWidget *widget);
extern int ami_run_mode;
extern int ami_editing_mode;
extern int ami_keyboard;
extern int ami_ekeyboard;
extern int bell_intensity;

extern gboolean ami_line_wraping_mode;
extern gboolean ami_use_underline;
extern gboolean esc_han_toggle;
extern gboolean unique_han;
extern gboolean support_status;
extern gboolean wait_wm;
extern gboolean allow_shuffle;
extern char *pix_dir_name;
extern int dock_style;
#endif
